#
# spec file for package libmatemixer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
%define _version 1.26

Name:           libmatemixer
Version:        1.26.1
Release:        1.1
Summary:        Mixer library for MATE Desktop
License:        LGPL-2.1-or-later
URL:            https://mate-desktop.org/
Group:          System/GUI/Other
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libpulse) >= 5.0
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
%glib2_gsettings_schema_requires

%description
libmatemixer is a mixer library for MATE desktop.

It provides an abstract API allowing access to mixer functionality
available in the PulseAudio, ALSA and OSS sound systems.

%package -n %{name}%{sover}
Summary:        Mixer library for MATE Desktop
Group:          System/Libraries
Recommends:     %{name}-lang
Provides:       %{name} = %{version}

%description -n %{name}%{sover}
libmatemixer is a mixer library for MATE desktop.

It provides an abstract API allowing access to mixer functionality
available in the PulseAudio, ALSA and OSS sound systems.

%lang_package

%package devel
Summary:        MATE Desktop keyboard configuration development files
Group:          Development/Libraries/X11
Requires:       %{name}%{sover} = %{version}

%description devel
libmatemixer is a mixer library for MATE desktop.

It provides an abstract API allowing access to mixer functionality
available in the PulseAudio, ALSA and OSS sound systems.

%prep
%setup -q

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --disable-static    \
  --enable-pulseaudio \
  --enable-alsa
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{sover} -p /sbin/ldconfig

%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%doc AUTHORS NEWS README
%{_libdir}/%{name}.so.%{sover}*
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/libmatemixer-null.so
%{_libdir}/%{name}/libmatemixer-pulse.so
%{_libdir}/%{name}/libmatemixer-alsa.so

%files devel
%license COPYING
%doc AUTHORS NEWS README
%doc %{_datadir}/gtk-doc/html
%{_includedir}/mate-mixer/
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%files lang -f %{name}.lang

%changelog
* Mon Nov 27 2023 Mihai Moldovan <ionic@ionic.de>
- Update to new upstream version 1.26.1:
  * Translations update
  * Remove weak pointers on dispose
* Tue Aug 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Update translations
  * build: set GETTEXT_PACKAGE=AC_PACKAGE_NAME
  * alsa: Add udev support
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * Use the correct macro for dynamic type's private.
  * build: Silent build warnings for distcheck.
  * Update translations.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0:
  * Avoid redundant redeclarations.
  * Update indent for Makefile.am.
  * Migrate from intltool to gettext.
  * Use WARN_CFLAGS which are only set with
  - -enable-compiler-warnings.
  * Update translations.
- Drop support for old openSUSE versions.
* Thu Jul 18 2019 Jonathan Brielmaier <jbrielmaier@suse.de>
- Update to version 1.23.0:
  * Translations update
  * avoid deprecated g_type_class_add_private
- remove patches:
  * libmatemixer-glib-2.48.patch: we don't support glib 2.48
    anymore
- BuildRequire glib >= 2.50
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * Require PulseAudio 5.0 and drop some old code.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Update translations.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GLib 2.50.
  * Update translations.
- Add libmatemixer-glib-2.48.patch: Restore GLib 2.48 support.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Update translations.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * Require PulseAudio 2.0 or newer.
  * Improve error checking in many places.
  * Some other PulseAudio fixes.
  * Some fixes and improvements in ALSA and OSS backends.
  * Some more fixes and cleanups.
  * Update translations.
  * Create Changelog from git.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Fix PulseAudio volume limits.
  * ALSA/OSS: Correctly disconnect device signals.
* Sun Nov 29 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Update translations.
* Thu Oct  8 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * OSS: Only use modify counter for polling on Linux, it is broken
    on BSDs.
  * ALSA: Fix FTBFS with old versions of ALSA.
  * ALSA: Fix fade.
* Tue Apr 14 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * First stable release
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Bugfixes release
* Sun Nov 23 2014 p.drouand@gmail.com
- Update to version 1.9.2 (unstable)
  + Improve pusleaudio and alsa support
- Add pkgconfig(alsa) make depend and pass --enable-alsa in configure
  options; build alsa backend
* Tue Nov 11 2014 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + New APIs: MateMixerDeviceSwitch, MateMixerStreamSwitch
* Sun Oct 26 2014 p.drouand@gmail.com
- Initial release (version 1.9.0)
